<?php
/**
 * SiteBill parent class
 * @author Kondin Dmitriy <kondin@etown.ru>
 */
define('DB_PREFIX', $__db_prefix);
if (  !defined('UPLOADIFY_TABLE')  ) 
{
    define('UPLOADIFY_TABLE', DB_PREFIX.'_uploadify');
}
if (  !defined('IMAGE_TABLE')  ) 
{
    define('IMAGE_TABLE', DB_PREFIX.'_image');
}

require_once(SITEBILL_DOCUMENT_ROOT.'/apps/system/lib/system/sitebill_registry.php');
require_once SITEBILL_DOCUMENT_ROOT.'/apps/system/lib/system/multilanguage/multilanguage.class.php';
Multilanguage::start('frontend',$_SESSION['_lang']);
Multilanguage::appendAppDictionary('system');

require_once SITEBILL_DOCUMENT_ROOT.'/apps/system/lib/system/debugger.class.php';
require_once SITEBILL_DOCUMENT_ROOT.'/apps/system/lib/system/logger.class.php';
require_once SITEBILL_DOCUMENT_ROOT.'/apps/system/lib/system/dbc.php';
if(!defined('DB_DSN')){
	define('DB_DSN','mysql:host='.$__server.';dbname='.$__db);
}
if(!defined('DB_ENCODING')){
	define('DB_ENCODING','cp1251');
}
if(!defined('SITE_ENCODING')){
	define('SITE_ENCODING','cp1251');
}
if(!defined('DB_USER')){
	define('DB_USER',$__user);
}
if(!defined('DB_PASS')){
	define('DB_PASS',$__password);
}
if(!defined('LOG_ENABLED')){
	define('LOG_ENABLED',false);
}
if(!defined('DEBUG_ENABLED')){
	define('DEBUG_ENABLED',false);
}
if(!defined('LOGGER_FILE')){
	define('LOGGER_FILE',SITEBILL_DOCUMENT_ROOT.'/log_000.txt');
}


class SiteBill {
    /**
     * Error message
     */
    var $error_message = false;
    var $uploadify_dir = '/cache/upl/';
    var $storage_dir = '/img/data/';
    private $config_loaded = false;
    
    
    /**
     * Constructor
     */
    function SiteBill() {
        global $__server, $__db, $__user, $__password, $sitebill_document_root;
		require_once SITEBILL_DOCUMENT_ROOT.'/apps/system/lib/template/template.php';
		$this->template = new Template();
		if ( $this->isDemo() ) {
		    $this->template->assign('show_demo_banners', '1');
		}
		$this->db = new Db( $__server, $__db, $__user, $__password );
		
		
		//$DB=DBC::getInstance();
		
    }
    
 	static function getAttachments($object_type, $object_id){
    	$attachments=array();
    	if((int)$object_id==0 || $object_type==''){
    		return $attachments;
    	}
    	$DBC=DBC::getInstance();
    	$stmt=$DBC->query('SELECT * FROM '.DB_PREFIX.'_attachment WHERE object_type=? AND object_id=?', array($object_type, $object_id));
    	if($stmt){
    		while($ar=$DBC->fetch($stmt)){
    			$attachments[]=$ar;
    		}
    	}
    	return $attachments;
    }
    
    static function appendAttachments($object_type, $object_id, $attachments){
    	if(count($attachments)>0){
    		$DBC=DBC::getInstance();
    		$q='INSERT INTO '.DB_PREFIX.'_attachment (file_name, object_id, object_type) VALUES (?,?,?)';
    		foreach($attachments as $attachment){
    			if(file_exists(SITEBILL_DOCUMENT_ROOT.'/cache/upl/'.$attachment)){
    				copy(SITEBILL_DOCUMENT_ROOT.'/cache/upl/'.$attachment, SITEBILL_DOCUMENT_ROOT.'/attachments/'.$attachment);
    				unlink(SITEBILL_DOCUMENT_ROOT.'/cache/upl/'.$attachment);
    				if(file_exists(SITEBILL_DOCUMENT_ROOT.'/cache/upl/thumbnail/'.$attachment)){
    					unlink(SITEBILL_DOCUMENT_ROOT.'/cache/upl/thumbnail/'.$attachment);
    				}
    				$DBC->query($q, array($attachment,$object_id,$object_type));
    			}
    		}
    	}
    }
    
    function escape($text){
    	if(get_magic_quotes_gpc()){
    		$text=mysql_real_escape_string(stripcslashes($text));
    	}else{
    		$text=mysql_real_escape_string($text);
    	}
    	return $text;
    }
    
	/**
     * Get breadcrumbs
     * @param array $items
     * @return string
     */
    function get_breadcrumbs ( $items ) {
        if ( count($items) > 0 ) {
            return implode(' / ', $items);
        }
        return '';
    }
    
    function get_ajax_functions () {
    	$rs='<script type="text/javascript" src="'.SITEBILL_MAIN_URL.'/apps/system/js/refresher.functions.js"></script>';
        return $rs;
    }
    
    /**
     * Get apps template full path
     * @param string $apps_name
     * @param string $theme
     * @param string $template_value
     * @return boolean
     */
    function get_apps_template_full_path ( $apps_name, $theme, $template_value ) {
    	if ( !file_exists(SITEBILL_DOCUMENT_ROOT.'/template/frontend/'.$theme.'/'.$apps_name.'/'.$template_value) ) {
    		if ( file_exists(SITEBILL_DOCUMENT_ROOT.'/apps/'.$apps_name.'/site/template/'.$template_value) ) {
    			return SITEBILL_DOCUMENT_ROOT.'/apps/'.$apps_name.'/site/template/'.$template_value;
    		} else {
    			echo Multilanguage::_('L_FILE')." ".SITEBILL_DOCUMENT_ROOT.'/apps/'.$apps_name.'/site/template/'.$template_value.'  ';
    			exit;
    		}
    	} else {
    		return SITEBILL_DOCUMENT_ROOT.'/template/frontend/'.$theme.'/'.$apps_name.'/'.$template_value;
    	}
    }
    
    /**
     * Get page by URI
     * @param string $uri uri
     * @return array
     */
    function getPageByURI ( $uri ) {
        global $__db_prefix;
        $uri = mysql_real_escape_string($uri);
        $uri = str_replace('/', '', $uri);
    	
    	$query = "select * from ".$__db_prefix."_page where uri='$uri'";
    	//echo $query;
    	$this->db->exec($query);
    	$this->db->fetch_assoc();
    	if ( $this->db->row['page_id'] > 0 ) {
    		return $this->db->row;
    	}
    	return false;
    }
    
    /**
     * Get session key
     * @param void
     * @return string
     */
    function get_session_key () {
    	return $_SESSION['key'];
    }
    
    /**
     * Delete session by key
     * @param string $session_key
     * @return void
     */
    function delete_session_key ( $session_key ) {
        $query = "delete from ".DB_PREFIX."_session where session_key='$session_key'";
        $this->db->exec($query);
        return $_SESSION['key'];
    }
    
    
    /**
     * Get session user ID
     * @param void
     * @return int
     */
    function getSessionUserId ( ) {
        global $init;
        
        $key = $_SESSION['key'];
        if ( $key != '' ) {
        	$query = "select user_id from ".DB_PREFIX."_session where session_key ='$key'";
        	//echo $query;
        	$this->db->exec($query);
        	$this->db->fetch_assoc();
        	$user_id = $this->db->row['user_id'];
        	if ( $user_id != '' and $user_id != 0 ) {
        		$this->user_id = $user_id;
        		$init->setUserId($user_id);
        		return $user_id;
        	} else {
        		$this->user_id = 0;
        		return 0;
        	}
        }
        $this->user_id = 0;
        return 0;
    }
    
    /**
     * Load uploadify images
     * @param string $session_code session code
     * @return array
     */
    function load_uploadify_images ( $session_code ) {
        $ra = array();
        $query = "select * from ".UPLOADIFY_TABLE." where session_code='$session_code' ORDER BY uploadify_id";
        $this->db->exec($query);
        $j = 0;
        while ( $this->db->fetch_assoc() ) {
        	$j++;
            $ra[] = $this->db->row['file_name'];
        }
        if ( $j == 0 ) {
        	return false;
        }
        return $ra;
    }
    
    /**
     * Edit image
     * @param string $action action
     * @param string $table_name table name
     * @param string $key key
     * @param int $record_id record ID
     * @return boolean
     */
    function editImageMulti( $action, $table_name, $key, $record_id, $name_template='' ) {
    	if ( !isset($record_id) or $record_id == 0 ) {
    		return false;
    	}
    	$path = SITEBILL_DOCUMENT_ROOT.'/img/data/';
    	$uploadify_path = SITEBILL_DOCUMENT_ROOT.$this->uploadify_dir;
    	
    	$ra = array();
    	//update image
    	$images = $this->load_uploadify_images($this->get_session_key());
    	if (!$images) {
    		return false;
    	}
    	
    	//print_r($images);
    	
        foreach ( $images as $image_name ) {
            $i++;
            $need_prv=0;
            $preview_name='';   
            if ( !empty($image_name) ) { 
                $arr=split('\.',$image_name);
                $ext=strtolower($arr[count($arr)-1]);
                if((1==$this->getConfigValue('seo_photo_name_enable')) AND ($name_template!='')){
                	$name_template=substr($name_template,0,150);
                	if($i==0){
                		$preview_name_no_ext=$name_template;
                		$prv_no_ext=$name_template."_prev";
                	}else{
                		$preview_name_no_ext=$name_template."_".$i;
                		$prv_no_ext=$name_template."_prev".$i;
                	}
                	
                	if(file_exists($path.$preview_name_no_ext.".".$ext)){
                		$rand=rand(0,1000);
	                	while(file_exists($path.$preview_name_no_ext."_".$rand.".".$ext)){
	                		$rand=rand(0,1000);
	                	}
	                	$preview_name=$preview_name_no_ext."_".$rand.".".$ext;
                		$prv=$prv_no_ext."_".$rand.".".$ext;
                	}else{
                		$preview_name=$preview_name_no_ext.".".$ext;
                		$prv=$prv_no_ext.".".$ext;
                	}
                }else{
                	$preview_name="img".uniqid().'_'.time()."_".$i.".".$ext;
	                $prv="prv".uniqid().'_'.time()."_".$i.".".$ext;
	                $preview_name_tmp="_tmp".uniqid().'_'.time()."_".$i.".".$ext;
                }
                
                if(in_array($ext,array('jpg','jpeg','gif','png'))){
                
               //print_r($this->config_array);	
               //echo $action.'_image_big_width';
                
                $big_width = $this->getConfigValue($action.'_image_big_width');
                if ($big_width == '') {
                	$big_width = $this->getConfigValue('news_image_big_width');
                }
                $big_height = $this->getConfigValue($action.'_image_big_height');
                if ( $big_height == '' ) {
                	$big_height = $this->getConfigValue('news_image_big_height');
                }
                
                $preview_width = $this->getConfigValue($action.'_image_preview_width');
                if ( $preview_width == '' ) {
                	$preview_width = $this->getConfigValue('news_image_preview_width');
                }
                $preview_height = $this->getConfigValue($action.'_image_preview_height');
                if ( $preview_height == '' ) {
                	$preview_height = $this->getConfigValue('news_image_preview_height');
                }
                
                list($width,$height)=$this->makePreview($uploadify_path.$image_name, $path.$preview_name, $big_width,$big_height, $ext,1);
                
                list($w,$h)=$this->makePreview($uploadify_path.$image_name, $path.$prv, $preview_width,$preview_height, $ext,'width');
                /*  ,        0600*/
                chmod($path.$preview_name, 0644);
                chmod($path.$prv, 0644);
                /**/
                
                }
                $ra[$i]['preview'] = $prv;
                $ra[$i]['normal'] = $preview_name;
                
            } 
        }
        $this->add_image_records($ra, $table_name, $key, $record_id);
        $this->delete_uploadify_images($this->get_session_key());
        return $ra;
    }
    
    /**
     * Edit file
     * @param string $action action
     * @param string $table_name table name
     * @param string $key key
     * @param int $record_id record ID
     * @return boolean
     */
    function editFileMulti( $action, $table_name, $key, $record_id ) {
    	$path = SITEBILL_DOCUMENT_ROOT.'/img/data/';
    	$uploadify_path = SITEBILL_DOCUMENT_ROOT.$this->uploadify_dir;
    	
    	$ra = array();
    	
    	//update image
    	$images = $this->load_uploadify_images($this->get_session_key());
    	
        foreach ( $images as $image_name ) {
            $i++;
            $need_prv=0;
            $preview_name='';   
            if ( !empty($image_name) ) { 
                $arr=split('\.',$image_name);
                $ext=strtolower($arr[count($arr)-1]);
                $preview_name="file".uniqid().'_'.time()."_".$i.".".$ext;
                $prv="ffile".uniqid().'_'.time()."_".$i.".".$ext;
                $preview_name_tmp="_tmp".uniqid().'_'.time()."_".$i.".".$ext;
                
                
                list($width,$height)=$this->makeMove($uploadify_path.$image_name, $path.$preview_name);
                $ra[$i]['preview'] = $preview_name;
            } 
        }
        $this->add_image_records($ra, $table_name, $key, $record_id);
        $this->delete_uploadify_images($this->get_session_key());
        return $ra;
    }
    
    function clear_uploadify_table(){
    	$uploadify_path = SITEBILL_DOCUMENT_ROOT.$this->uploadify_dir;
        
        $ra = array();
        $query = "SELECT * FROM ".UPLOADIFY_TABLE;
        $this->db->exec($query);
        while ( $this->db->fetch_assoc() ) {
            $ra[] = $this->db->row['file_name'];
        }
        if ( count($ra) > 0 ) {
            foreach ( $ra as $image_name ) {
                if ( is_file($uploadify_path.$image_name) ) {
                    unlink($uploadify_path.$image_name);
                }
            }
        }
        $this->db->exec("TRUNCATE TABLE ".UPLOADIFY_TABLE);
        return true;
    }
    
	function clear_captcha_session_table(){
		$limit_date=date('Y-m-d H:i:s', (time()-24*3600));
		$q='DELETE FROM '.DB_PREFIX.'_captcha_session WHERE start_date<\''.$limit_date.'\'';
    	$this->db->exec($q);
        return true;
    }
    
	function clear_session_table(){
		$limit_date=date('Y-m-d H:i:s', (time()-24*3600));
		$q='DELETE FROM '.DB_PREFIX.'_session WHERE start_date<\''.$limit_date.'\'';
    	$this->db->exec($q);
        return true;
    }
    
    /**
     * Delete uploadify images
     * @param string $session_code session code
     * @return array
     */
    function delete_uploadify_images ( $session_code ) {
    	$uploadify_path = SITEBILL_DOCUMENT_ROOT.$this->uploadify_dir;
        
        $ra = array();
        $query = "select * from ".UPLOADIFY_TABLE." where session_code='$session_code'";
        $this->db->exec($query);
        while ( $this->db->fetch_assoc() ) {
            $ra[] = $this->db->row['file_name'];
        }
        if ( count($ra) > 0 ) {
            foreach ( $ra as $image_name ) {
                if ( is_file($uploadify_path.$image_name) ) {
                    unlink($uploadify_path.$image_name);
                }
            }
        }
        $query = "delete from ".UPLOADIFY_TABLE." where session_code='$session_code'";
        $this->db->exec($query);
        return true;
    }
    
	/**
     * Delete uploadify image
     * @param string $image_name image_name
     * @return array
     */
    function delete_uploadify_image ( $image_name ) {
    	//$data=explode('/',$image_name);
    	$file_name=$image_name;
    	$uploadify_path = SITEBILL_DOCUMENT_ROOT.$this->uploadify_dir;
        $query = "DELETE FROM ".UPLOADIFY_TABLE." where file_name='$file_name'";
        $this->db->exec($query);
        unlink($uploadify_path.$file_name);
        return true;
    }

    function get_ajax_auth_form () {
        if ( SITEBILL_MAIN_URL != '' ) {
            $add_folder = SITEBILL_MAIN_URL.'/';
        }
        $rs .= '<form method="post" onsubmit="run_login(\'login\', \'cp1251\', \''.$_SERVER['SERVER_NAME'].$add_folder.'\'); return false;">';
        $rs .= '';
        $rs .= '<table border="0">';
        if ( $this->getError() and $this->GetErrorMessage() != 'not login' ) {
            $rs .= '<tr>';
            $rs .= '<td colspan="2"><span class="error">'.$this->GetErrorMessage().'</span></td>';
            $rs .= '</tr>';
        }
        $rs .= '<tr>';
        $rs .= '<td class="special" colspan="2"><div id="error_message"></div></td>';
        $rs .= '</tr>';
        
        $rs .= '<tr>';
        $rs .= '<td class="special">'.Multilanguage::_('L_LOGIN').' </td>';
        $rs .= '<td class="special"><input type="text" name="login" id="login"></td>';
        $rs .= '</tr>';
        
        $rs .= '<tr>';
        $rs .= '<td class="special">'.Multilanguage::_('L_PASSWORD').' </td>';
        $rs .= '<td class="special"><input type="password" name="password" id="password"></td>';
        $rs .= '</tr>';
        $rs .= '<tr>';
        $rs .= '<td class="special">';
        if ( $this->getConfigValue('allow_register_admin') ) {
            $rs .= '<a href="#" onclick="run_command(\'register\', \'cp1251\', \''.$_SERVER['SERVER_NAME'].$add_folder.'\'); return false;">'.Multilanguage::_('L_AUTH_REGISTRATION').'</a>';
        }
        $rs .= '</td>';
        $rs .= '<td class="special"><input type="submit" value="'.Multilanguage::_('L_LOGIN_BUTTON').'" onclick="run_login(\'login\', \'cp1251\', \''.$_SERVER['SERVER_NAME'].$add_folder.'\'); return false;"></td>';
        $rs .= '</tr>';
        $rs .= '</table>';
        $rs .= '';
        $rs .= '</form>';
        return $rs;
    }
    
    /**
     * Get simple auth form
     * @param string $action
     * @param boolean $register
     * @param boolean $remind
     * @return string
     */
    function get_simple_auth_form ( $action = '/login/', $register = true, $remind = true ) {
        if ( SITEBILL_MAIN_URL != '' ) {
            $add_folder = '/'.SITEBILL_MAIN_URL;
        }
        if($this->getConfigValue('theme')=='albostar'){
        	$rs .= '<form method="post" action="'.SITEBILL_MAIN_URL.$action.'">';
	        $rs .= '';
	        
	        if ( $this->getError() and $this->GetErrorMessage() != 'not login' ) {
	            $rs .= '<div>';
	            $rs .= '<span class="error">'.$this->GetErrorMessage().'</span>';
	           	$rs .= '</div>';
	        }
	        
	        
	        $rs .= '<label>'.Multilanguage::_('L_AUTH_LOGIN').'</label>';
	        $rs .= '<input type="text" name="login" id="login">';
	        $rs .= '<br />';
	        
	        $rs .= '<label>'.Multilanguage::_('L_AUTH_PASSWORD').'</label>';
	        $rs .= '<input type="password" name="password" id="password">';
	        $rs .= '<input type="submit" value="">';
        	if ( $register ) {
	        	$rs .= '<br />';
	            $rs .= '<a href="'.SITEBILL_MAIN_URL.'/register/">'.Multilanguage::_('L_AUTH_REGISTRATION').'</a>';
	        }
	        if ( $remind ) {
	        	$rs .= '<br />';
	        	$rs .= '<a href="'.SITEBILL_MAIN_URL.'/remind/">'.Multilanguage::_('L_AUTH_FORGOT_PASS').'</a>';
	        }
	        
	        $rs .= '<input type="hidden" name="do" value="login">';
	        $rs .= '</form>';
        }else{
        	$rs .= '<form method="post" action="'.SITEBILL_MAIN_URL.$action.'">';
	        $rs .= '';
	        $rs .= '<table border="0">';
	        if ( $this->getError() and $this->GetErrorMessage() != 'not login' ) {
	            $rs .= '<tr>';
	            $rs .= '<td colspan="2"><span class="error">'.$this->GetErrorMessage().'</span></td>';
	            $rs .= '</tr>';
	        }
	        
	        
	        $rs .= '<tr>';
	        $rs .= '<td class="special">'.Multilanguage::_('L_AUTH_LOGIN').' </td>';
	        $rs .= '<td class="special"><input type="text" name="login" id="login"></td>';
	        $rs .= '</tr>';
	        
	        $rs .= '<tr>';
	        $rs .= '<td class="special">'.Multilanguage::_('L_AUTH_PASSWORD').' </td>';
	        $rs .= '<td class="special"><input type="password" name="password" id="password"></td>';
	        $rs .= '</tr>';
	        $rs .= '<tr>';
	        $rs .= '<td class="special">';
	        
	        if ( $register ) {
	            $rs .= '<a href="'.SITEBILL_MAIN_URL.'/register/">'.Multilanguage::_('L_AUTH_REGISTRATION').'</a>';
	        }
	        if ( $remind ) {
	        	$rs .= '<br><a href="'.SITEBILL_MAIN_URL.'/remind/">'.Multilanguage::_('L_AUTH_FORGOT_PASS').'</a>';
	        }
	        
	        $rs .= '</td>';
	        $rs .= '<td class="special"><input type="submit" value="'.Multilanguage::_('L_AUTH_ENTER').'"></td>';
	        $rs .= '</tr>';
	        $rs .= '</table>';
	        $rs .= '<input type="hidden" name="do" value="login">';
	        $rs .= '</form>';
        }
        
        return $rs;
    }
    
    
    /**
     * Add image data records
     * @param array $images images
     * @param string $table_name table name
     * @param string $key key
     * @param int $record_id record id
     * @return boolean
     */
    function add_image_records ( $images, $table_name, $key, $record_id ) {
    	//print_r($images);
    	foreach ( $images as $item_id => $item_array ) {
    		$query = "insert into ".IMAGE_TABLE." (normal, preview) values ('".$item_array['normal']."', '".$item_array['preview']."')";
    		//echo 'q = '.$query.'<br>';
    		$this->db->exec($query);
    		if ( !$this->db->success ) {
    			echo $this->db->error.'<br>';
    		}
    		$image_id = $this->db->last_insert_id();
    		$this->add_table_image_record($table_name, $key, $record_id, $image_id);
    	}
    }
    
    /**
     * Add table_image record
     * @param int $record_id record id
     * @param int $image_id image id
     * @return boolean
     */
    function add_table_image_record($table_name, $key, $record_id, $image_id) {
    	$query = "insert into ".DB_PREFIX."_".$table_name."_image (".$key.", image_id, sort_order) values ('".$record_id."', '".$image_id."', '".$image_id."')";
    	//echo 'q = '.$query.'<br>';
    	$this->db->exec($query);
    	if ( !$this->db->success ) {
    		echo $this->db->error.'<br>';
    	}
    	return true;
    }
    
   /**
     * Get Plupload plugin (http://www.plupload.com/)
     * Only html4 version available (not attached files for others)
     * @param string $session_code session code
     * @return string
     */
    function getPluploaderPlugin($session_code){
    	$this->clear_uploadify_table();
    	global $folder;
    	$rs .= '
    	
    		<style type="text/css">@import url('.$folder.'/apps/system/js/plupload/jquery.plupload.queue/css/jquery.plupload.queue.css);</style>
			<script type="text/javascript" src="'.$folder.'/apps/system/js/plupload/plupload.full.js"></script>
			<script type="text/javascript" src="'.$folder.'/apps/system/js/plupload/jquery.plupload.queue/jquery.plupload.queue.js">
			<script type="text/javascript" src="http://bp.yahooapis.com/2.4.21/browserplus-min.js"></script>
			<script>        
		       $(function() {
		       		function log(msg){
		       			 $("#log").append(msg + "\n");
		       		
		       		};
		       		
		       		var del=[];
		       
					$("#html4_uploader").pluploadQueue({
						runtimes : \'html4\',
						multiple_queues: true,
						url : "'.$folder.'/apps/system/js/uploadify/uploadify.php?session='.$session_code.'",
						init : {
							FileUploaded: function(up, file, info) {
								if (info.response.indexOf("wrong_ext") != -1){
									file.status = plupload.FAILED;
									up.trigger("UploadProgress", file);
								}else if(info.response.indexOf("max_file_size") != -1){
									file.status = plupload.FAILED;
									up.trigger("UploadProgress", file);
								}
							},
							
						}
					});
				});  
		    </script>  
			<div id="log"></div>
			<div id="html4_uploader">You browser doesnt support simple upload forms. Are you using Lynx?</div>';
    	return $rs;
    }
    
   /**
     * Get uploadify plugin
     * @param string $session_code session code
     * @return string
     */
    function getUploadifyPlugin ( $session_code ) {
    	$this->clear_uploadify_table();
        global $folder;
        $rs = '';
        $rs .= '
<link href="'.$folder.'/apps/system/js/uploadify/uploadify.css" type="text/css" rel="stylesheet" />

		
<script type="text/javascript" src="'.$folder.'/apps/system/js/uploadify/jquery.uploadify.js"></script>
<script type="text/javascript">
var uploadedfiles = 0;
var maxQueueSize = 100;
var queueSize = 0;
$(document).ready(function() {
	var max_item_count='.((int)$this->getConfigValue('photo_per_data')>0 ? (int)$this->getConfigValue('photo_per_data') : 1000).';
	
	
	
  $(\'#file_upload\').uploadify({
    \'swf\'  : \''.$folder.'/apps/system/js/uploadify/uploadify.swf\',
    \'uploader\'    : \''.$folder.'/apps/system/js/uploadify/uploadify.php?session='.$session_code.'\',
    \'cancelImg\' : \''.$folder.'/apps/system/js/uploadify/uploadify-cancel.png\',
    \'folder\'    : \''.$folder.'/cache/upl\',
    \'auto\'      : true,
	\'fileTypeExts\': \'*.jpg;*.jpeg;*.png;*.gif\',
	\'multi\': true,	
	\'queueSizeLimit\': 100,
		\'buttonText\': \''.Multilanguage::_('L_PHOTO').'\',	
	\'buttonImg\': \''.$folder.'/img/button_img_upl.png\',	
    \'onUploadSuccess\': function(fileObj, response, data) {
    					queueSize++;
    					if ( response == \'max_file_size\' ) {
    						alert(\''.Multilanguage::_('L_MESSAGE_MAX_UPL_SIZE').' '.ini_get('upload_max_filesize').' \');
    						return false;
    					}
    					if ( response == \'wrong_ext\' ) {
    						alert(\''.Multilanguage::_('L_MESSAGE_AVIALABLE_EXTS').' *.jpg,*.jpeg,*.png,*.gif\');
    						return false;
    					}
    					if ( queueSize > maxQueueSize ) {
    						alert(\''.Multilanguage::_('L_MESSAGE_MAX_FILES_COUNT').'\');
    						return false;
    					}
    					var imgs_count=$("div.preview_admin").length+$("#filecollector img").length;
    					imgs_count++;
    					if(imgs_count==max_item_count){
    						$(\'#file_uploadUploader\').hide();
						}
    					addFileNotify(queueSize);
    					addFileInCollector(response);
    					
    				}
                    
    });
    
});
function addFileNotify ( queueSize ) {
	$(\'#filenotify\').html( \'  : \' + queueSize + \' ()\' );
}
function addFileInCollector ( filePath ) {
	var temp=new Array();
	temp=filePath.split(\'/\');
	var f=temp[temp.length-1];
	var cont=$(\'#filecollector\').html();
	cont=cont+\'<div><img src="\'+filePath+\'" width="50px" /><a class="kill_upl" href="javascript:void(0)" alt="\'+f+\'">X</a></div>\';
	$(\'#filecollector\').html(cont);
	
}

$(document).ready(function() {

	$(\'a.kill_upl\').live(\'click\',function(){
		var imgs_count=$("div.preview_admin").length+$("#filecollector img").length;
		var max_item_count='.((int)$this->getConfigValue('photo_per_data')>0 ? (int)$this->getConfigValue('photo_per_data') : 1000).';
		var url=\'/js/ajax.php?action=delete_uploadify_image&img_name=\'+$(this).attr(\'alt\');
		//alert(url);
		$.getJSON(url,{},function(data){
		
		});
		var parent=$(this).parent(\'div\');
		parent.html(\'\');
		//alert($(this).attr(\'alt\'));
		
		imgs_count--;
		if(imgs_count<max_item_count){
    		$(\'#file_uploadUploader\').show();
		}
	});
	//$.getJSON(\'/js/ajax.php?action=delete_uploadify_image&img_name=\'+file,{},function(data){
		
});






</script>
<input id="file_upload" name="file_upload" type="file" />
<div id="filenotify"></div>
<div id="filecollector"></div>
        ';
        return $rs;
    }
    
    /**
     * Get uploadify plugin
     * @param string $session_code session code
     * @return string
     */
    function getUploadifyFilePlugin ( $session_code ) {
    	$this->clear_uploadify_table();
    	$id=md5(time().rand(1000,9999));
        global $folder;
        
        $rs = '';
        $rs .= '
<link href="'.$folder.'/apps/system/js/uploadify/uploadify.css" type="text/css" rel="stylesheet" />
<script type="text/javascript" src="'.$folder.'/apps/system/js/uploadify/jquery.uploadify.js"></script>
<script type="text/javascript">
var uploadedfiles = 0;
var maxQueueSize = 100;
var queueSize = 0;
$(document).ready(function() {
  $(\'#'.$id.'\').uploadify({
    \'swf\'  : \''.$folder.'/apps/system/js/uploadify/uploadify.swf\',
    \'uploader\'    : \''.$folder.'/apps/system/js/uploadify/uploadify.php?session='.$session_code.'\',
    \'cancelImg\' : \''.$folder.'/apps/system/js/uploadify/uploadify-cancel.png\',
    \'folder\'    : \''.$folder.'/cache/upl\',
    \'auto\'      : true,
	\'fileTypeExts\': \'*.jpg;*.png;*.gif\',
	\'multi\': true,	
	\'queueSizeLimit\': 100,
		\'buttonText\': \''.Multilanguage::_('L_FILE').'\',	
	\'buttonImg\': \''.$folder.'/img/button_img_upl.png\',	
    \'onUploadSuccess\': function(fileObj, response, data) {
    					queueSize++;
    					if ( response == \'max_file_size\' ) {
    						alert(\''.Multilanguage::_('L_MESSAGE_MAX_UPL_SIZE').' '.ini_get('upload_max_filesize').' \');
    						return false;
    					}
    					if ( response == \'wrong_ext\' ) {
    						alert(\''.Multilanguage::_('L_MESSAGE_AVIALABLE_EXTS').' png, jpg, tif, jpeg, doc,docx, xls, xlsx, pdf, txt, zip, rar\');
    						return false;
    					}
    					if ( queueSize > maxQueueSize ) {
    						alert(\''.Multilanguage::_('L_MESSAGE_MAX_FILES_COUNT').'\');
    						return false;
    					}
    					addFileNotify(queueSize);
    				}
                    
    });
});
function addFileNotify ( queueSize ) {
	$(\'#filenotify\').html( \'  : \' + queueSize + \' ()\' );
}
</script>
<input id="'.$id.'" name="file_upload" type="file" />
<div id="filenotify"></div>
        ';
        return $rs;
    }
    
    
    /**
     * Is demo
     * @param void
     * @return boolean
     */
    function isDemo () {
        global $__user, $__db;
        if ( preg_match('/rumantic_estate/', $__db) ) {
            return true;
        }
        return false;
    }
    
    /**
     * Demo function disabled
     * @param void
     * @return string
     */
    function demo_function_disabled () {
        return Multilanguage::_('L_MESSAGE_THIS_IS_TRIAL_COMMON');
    }
    
    
    /**
     * Load config
     * @param
     * @return
     */
    function loadConfig () {
    	$this->config_array['per_page'] = 25;
    	$this->config_array['site_title'] = ' ';
    	 
    	$this->config_array['news_image_big_width'] = 350;
    	$this->config_array['news_image_big_height'] = 350;
    	 
    	$this->config_array['news_image_preview_width'] = 84;
    	$this->config_array['news_image_preview_height'] = 84;
    
    	$this->config_array['gallery_image_big_width'] = 800;
    	$this->config_array['gallery_image_big_height'] = 600;
    	 
    	$this->config_array['gallery_image_preview_width'] = 200;
    	$this->config_array['gallery_image_preview_height'] = 200;
    	 
    	$this->config_array['auto_image_big_width'] = 800;
    	$this->config_array['auto_image_big_height'] = 600;
    	 
    	$this->config_array['auto_image_preview_width'] = 200;
    	$this->config_array['auto_image_preview_height'] = 200;
    	 
    	$this->config_array['data_image_big_width'] = 800;
    	$this->config_array['data_image_big_height'] = 600;
    	 
    	$this->config_array['data_image_preview_width'] = 200;
    	$this->config_array['data_image_preview_height'] = 200;
    	 
    	$this->config_array['shop_product_image_big_width'] = 800;
    	$this->config_array['shop_product_image_big_height'] = 600;
    	 
    	$this->config_array['shop_product_image_preview_width'] = 200;
    	$this->config_array['shop_product_image_preview_height'] = 200;
    	 
    	$this->config_array['vendor_image_big_width'] = 800;
    	$this->config_array['vendor_image_big_height'] = 600;
    	 
    	$this->config_array['vendor_image_preview_width'] = 50;
    	$this->config_array['vendor_image_preview_height'] = 50;
    	 
    	$this->config_array['news_image_preview_height'] = 84;
    	
    	$this->config_array['topic_image_big_width'] = 800;
    	$this->config_array['topic_image_big_height'] = 600;
    	
    	$this->config_array['topic_image_preview_width'] = 200;
    	$this->config_array['topic_image_preview_height'] = 200;
    
    	if ( !$this->config_loaded ) {
    		if ( !is_object($this->db) ) {
    			global $__server, $__db, $__user, $__password;
    			$this->db = new Db( $__server, $__db, $__user, $__password );
    		}
    		$query='SELECT * FROM '.DB_PREFIX.'_config ORDER BY config_key';
    		$this->db->exec($query);
    		while ($this->db->fetch_assoc()){
    			$this->config_loaded = true;
    			$this->config_array[$this->db->row['config_key']] = $this->db->row['value'];
    		}
    	}
    }
    
    
    /**
     * Delete image
     * @param string $table_name table name
     * @param int $image_id image id
     * @return boolean
     */
    function deleteImage ( $table_name, $image_id ) {
    	//delete records from land_image
    	$query = "delete from ".DB_PREFIX."_".$table_name."_image where image_id=$image_id";
    	$this->db->exec($query);
    	
    	//delete image files
    	$this->deleteImageFiles( $image_id );
    	
    	//delete image records
    	$query = "delete from ".IMAGE_TABLE." where image_id=$image_id";
    	$this->db->exec($query);
		return true;    	
    }
    
    /**
     * Reorder image
     * @param $action
     * @param $image_id
     * @param $key 
     * @param $key_value
     * @param $direction
     * @return mixed
     */
    function reorderImage($action, $image_id, $key, $key_value, $direction) {
    	//get current image info
    	$query = "select ".$action."_image_id, sort_order from ".DB_PREFIX.'_'.$action."_image where image_id=$image_id";
    	//echo $query.'<br>';
    	$this->db->exec($query);
    	$this->db->fetch_array();
    	$rr = $this->db->row;
    	
    	$record_image_id = $rr[0];
    	//echo "record_image_id = $record_image_id<br>";
    	$sort_order = $rr[1];
    	//echo "sort_order = $sort_order<br>";
    	if ( $direction == 'down' ) {
	    	//get next image id
    		$query = "select ".$action."_image_id, sort_order from ".DB_PREFIX.'_'.$action."_image where sort_order > $sort_order and $key = $key_value order by sort_order asc";
    	    $this->db->exec($query);
    	    $this->db->fetch_array();
    	    $rr = $this->db->row;
    	    
    		//$rr = sql_select_array($query);
    		
    		$next_record_image_id = $rr[0];
    		//echo "next_record_image_id = $next_record_image_id<br>";
    		if ( !isset($next_record_image_id) ) {
    			return;
    		}
    		$next_sort_order = $rr[1];
    		//echo "next_sort_order = $next_sort_order<br>";
    		
	    	//replace
    		$query = "update ".DB_PREFIX.'_'.$action."_image set sort_order=$next_sort_order where ".$action."_image_id=$record_image_id";
    	    $this->db->exec($query);
    		//sql_query($query);
    	
    		$query = "update ".DB_PREFIX.'_'.$action."_image set sort_order=$sort_order where ".$action."_image_id=$next_record_image_id";
    	    $this->db->exec($query);
    		//sql_query($query);
    		
    	}
    	
    	if ( $direction == 'up' ) {
	    	//get next image id
    		$query = "select ".$action."_image_id, sort_order from ".DB_PREFIX.'_'.$action."_image where sort_order < $sort_order and $key = $key_value order by sort_order desc";
    		$this->db->exec($query);
    	    $this->db->fetch_array();
    	    $rr = $this->db->row;
    		//$rr = sql_select_array($query);
    		$next_record_image_id = $rr[0];
    		//echo "next_record_image_id = $next_record_image_id<br>";
    		if ( !isset($next_record_image_id) ) {
    			return;
    		}
    		$next_sort_order = $rr[1];
    		//echo "next_sort_order = $next_sort_order<br>";
    	
	    	//replace
    		$query = "update ".DB_PREFIX.'_'.$action."_image set sort_order=$next_sort_order where ".$action."_image_id=$record_image_id";
    	    $this->db->exec($query);
    		//sql_query($query);
    	
    		$query = "update ".DB_PREFIX.'_'.$action."_image set sort_order=$sort_order where ".$action."_image_id=$next_record_image_id";
    	    $this->db->exec($query);
    		//sql_query($query);
    		
    	}
    	
    	//get next image
    	
    }
    
    function reorderTopics($orderArray){
    	//print_r($orderArray);
    	if(count($orderArray)>0){
    		foreach($orderArray as $k=>$v){
    			$query='UPDATE '.DB_PREFIX.'_topic SET `order`='.((int)$v).' WHERE id='.((int)$k);
    			$this->db->exec($query);
    		}
    	}
    	
    }
    
    /**
     * Delete image files
     * @param $image_id image id
     * @return boolean
     */
    function deleteImageFiles( $image_id ) {
    	$path = SITEBILL_DOCUMENT_ROOT.$this->storage_dir;
    	
    	$query = "select * from ".IMAGE_TABLE." where image_id=$image_id";
    	$this->db->exec($query);
    	while ( $this->db->fetch_assoc() ) {
    		$preview = $this->db->row['preview'];
    		$normal = $this->db->row['normal'];
            @unlink($path.$preview);
            @unlink($path.$normal);
    	}
    	return true;
    }

    /**
     * Get config value
     * @param string $key key
     * @return string
     */
    function getConfigValue ( $key ) {
        //echo '<b>need config key = '.$key.'</b><br>';
    	if ( !$this->config_loaded ) {
    	    //echo '<b>load config</b><br>';
    		$this->loadConfig();
    	}
    	if ( isset($this->config_array[$key]) ) {
    	    //echo "cfg: $key = ".$this->config_array[$key]."<br>";
    		return $this->config_array[$key];
    	}
    	return false;
    }
    
    /*function setConfigValue ( $key, $value ) {
    	if ( !$this->config_loaded ) {
    		$this->loadConfig();
    	}
    	$this->config_array[$key]=$value;
    }*/
    
    /**
     * Get debug mode
     * @param void
     * @return boolean
     */
    function getDebugMode() {
        return DEBUG_MODE;
    }
    
    /**
     * Set debug mode 
     * @param boolean
     * @return void
     */
    function setDebugMode ( $debug_mode ) {
        return;
    }
    
    /**
     * Get value
     * @param string $key key
     * @return string
     */
    function getRequestValue( $key ) {
    	if ( isset($_GET[$key]) or  isset($_POST[$key]) ) {
    		$value = (isset($_GET[$key])) ? $_GET[$key] : $_POST[$key];
    		return $value;
    	}
    }
    
    /**
     * Set request value
     * @param string $key key
     * @param string $value value
     * @return void
     */
    function setRequestValue ( $key, $value ) {
        $_POST[$key] = $value;
        return;
    }

    /**
     * Rise error 
     * @param string $error error message
     * @return void
     */
    function riseError ( $error_message ) {
        $this->error_message = $error_message;
        $this->error_state = true;
    }
    
    /**
     * Get error 
     * @param void
     * @return boolean
     */
    function getError ( ) {
        return $this->error_message;
    }
    
    /**
     * Get error message
     * @param void
     * @return string
     */
    function GetErrorMessage () {
        return $this->error_message;
    }
    
    /**
     * Write log message
     * @param string $message message
     * @return void
     */
    function writeLog ( $message ) {
        global $debug_log;
        if ( !preg_match('/Z:\/home/',SITEBILL_DOCUMENT_ROOT) ) {
            return;
        }
        if (!$handle = @fopen($debug_log, 'a')) {
            //echo "Cannot open error log file ($debug_log)";
            return;
        }
        $error_message = date("Y-m-d H:i:s ").$message."\n";
        if (fwrite($handle, $error_message) === FALSE) {
            //echo "Cannot write to erro log file ($debug_log)";
            return;
        }
        fclose($handle);
        return;
    }
    
    /**
     * Get image list admin
     * @param string $action action
     * @param string $table_name table name
     * @param string $key key
     * @param int $record_id record id
     * @return string
     */
    function getImageListAdmin ( $action, $table_name, $key, $record_id, &$callback_count=NULL ) {
    	global $__db_prefix;
    	if ( SITEBILL_MAIN_URL != '' ) {
    	    $url = SITEBILL_MAIN_URL.'/'.$this->storage_dir;
    	} else {
    	    $url = $this->storage_dir;
    	}
    	
    	
    	$query = "select i.* from ".DB_PREFIX."_".$table_name."_image as li, ".IMAGE_TABLE." as i where li.".$key."=$record_id and li.image_id=i.image_id order by li.sort_order";
    	//echo $query;
    	
    	$this->db->exec($query);
    	$i=0;
    	$rs .= '<script type="text/javascript" src="'.SITEBILL_MAIN_URL.'/apps/system/js/dataimagelist.js"></script>';
    	$rs .= '<script type="text/javascript">DataImagelist.attachDblclick();</script>';
    	while ( $this->db->fetch_assoc() ) {
	    	//$up_link = "?action=".$action."&do=edit&".$key."=$record_id&subdo=up_image&image_id=".$this->db->row['image_id'];
	    	//$down_link = "?action=".$action."&do=edit&".$key."=$record_id&subdo=down_image&image_id=".$this->db->row['image_id'];
	    		
	    		
	    	//$up_link_img = '<a href="'.$up_link.'"><img src="'.SITEBILL_MAIN_URL.'/img/up.gif" border="0" alt="" title=""></a>';
	    	//$down_link_img = '<a href="'.$down_link.'"><img src="'.SITEBILL_MAIN_URL.'/img/down1.gif" border="0" alt="" title=""></a>';
    	    
    		//$delete_link = "?action=".$action."&do=edit&".$key."=$record_id&subdo=delete_image&image_id=".$this->db->row['image_id'];
    		
    		$rs .= '<div class="preview_admin" style="padding: 2px; border: 1px solid gray;">
    		<table border="0" id="data_gallery">';
    		if(isset($this->db->row['title'])){
    			$rs .= '<tr><td class="field_tab" style="height:20px; border: 1px solid gray;" alt="'.$this->db->row['image_id'].'">'.$this->db->row['title'].'<td></tr>';
    		}
    		if(isset($this->db->row['description'])){
    			$rs .= '<tr><td class="field_tab_description" style="height:20px; border: 1px solid gray;" alt="'.$this->db->row['image_id'].'">'.$this->db->row['description'].'<td></tr>';
    		}
    		
    		$rs .= '<tr>
    		<td>
    		<img src="'.$url.''.$this->db->row['preview'].'" border="0" align="left"/><br>
    		</td>
    		<td>';
    		//<a href="'.$delete_link.'" onclick="return confirm(\''.Multilanguage::_('L_MESSAGE_REALLY_WANT_DELETE').'\');"></a>
    		//'.$up_link_img.'
    		//'.$down_link_img.'
    		$rs .= '<a href="javascript:void(0);" onClick="DataImagelist.deleteImage(this,'.$this->db->row['image_id'].','.$record_id.',\''.$table_name.'\',\''.$key.'\')"><img src="'.SITEBILL_MAIN_URL.'/apps/admin/admin/template/img/delete.png" width="16" border="0" alt="" title=""></a>
    		<a href="javascript:void(0);" onClick="DataImagelist.upImage(this,'.$this->db->row['image_id'].','.$record_id.',\''.$table_name.'\',\''.$key.'\')"><img src="'.SITEBILL_MAIN_URL.'/img/up.gif" border="0" alt="" title=""></a>
    		<a href="javascript:void(0);" onClick="DataImagelist.downImage(this,'.$this->db->row['image_id'].','.$record_id.',\''.$table_name.'\',\''.$key.'\')"><img src="'.SITEBILL_MAIN_URL.'/img/down1.gif" border="0" alt="" title=""></a></td>
    		</tr>
    		</table>
    		</div>';
    		$rs .= '<div style="clear: both;"></div>';
    		$i++;
    	}
    	if($callback_count!==NULL){
    		$callback_count=$i;
    	}
    	//echo $rs;
    	
    	return $rs;
    }
    
    /**
     * Get file list admin
     * @param string $action action
     * @param string $table_name table name
     * @param string $key key
     * @param int $record_id record id
     * @return string
     */
    function getFileListAdmin ( $action, $table_name, $key, $record_id ) {
    	global $__db_prefix;
    	if ( SITEBILL_MAIN_URL != '' ) {
    	    $url = SITEBILL_MAIN_URL.'/'.$this->storage_dir;
    	} else {
    	    $url = $this->storage_dir;
    	}
    	
    	
    	$query = "select i.* from ".DB_PREFIX."_".$table_name."_image as li, ".IMAGE_TABLE." as i where li.".$key."=$record_id and li.image_id=i.image_id order by li.sort_order";
    	//echo $query;
    	
    	$this->db->exec($query);
    	while ( $this->db->fetch_assoc() ) {
	    	$up_link = "?action=".$action."&do=edit&".$key."=$record_id&subdo=up_image&image_id=".$this->db->row['image_id'];
	    	$down_link = "?action=".$action."&do=edit&".$key."=$record_id&subdo=down_image&image_id=".$this->db->row['image_id'];
	    		
	    		
	    	$up_link_img = '<a href="'.$up_link.'"><img src="'.SITEBILL_MAIN_URL.'/img/up.gif" border="0" alt="" title=""></a>';
	    	$down_link_img = '<a href="'.$down_link.'"><img src="'.SITEBILL_MAIN_URL.'/img/down1.gif" border="0" alt="" title=""></a>';
    	    
    		$delete_link = "?action=".$action."&do=edit&".$key."=$record_id&subdo=delete_image&image_id=".$this->db->row['image_id'];
    		$rs .= '<div class="preview_admin" style="padding: 2px; border: 1px solid gray;">
    		<table border="0">
    		<tr>
    		<td>
    		<a href="'.$url.$this->db->row['preview'].'" target="_blank"><img src="/img/file.png" border="0" align="left"/></a><br>
    		</td>
    		<td>
    		<a href="'.$delete_link.'" onclick="return confirm(\''.Multilanguage::_('L_MESSAGE_REALLY_WANT_DELETE').'\');">'.Multilanguage::_('L_DELETE_LC').'</a>
    		'.$up_link_img.'
    		'.$down_link_img.'
    		</td>
    		</tr>
    		</table>
    		</div>';
    		$rs .= '<div style="clear: both;"></div>';
    	}
    	//echo $rs;
    	
    	return $rs;
    }
    
    
	/**
	 * Get page links list
	 * @param int $cur_page current page number
	 * @param int $total 
	 * @param int $per_page
	 * @param array $params
	 * @return array
	 */
	function get_page_links_list ($page, $total, $per_page, $params ) {
	    if ( $total <= $per_page ) {
	        return '';
	    }
	     
	    //print_r($params);
	    $pairs = array();
	    unset($params['page']);
	    if(count($params)>0){
		    foreach ( $params as $key => $value ) {
		        if(is_array($value)){
	        		if(count($value)>0){
	        			foreach($value as $v){
	        				if($v!=''){
	        					$pairs[] = $key.'[]='.$v;
	        				}
	        			}
	        		}
	        	}elseif ( $value != '' ) {
		            $pairs[] = "$key=$value";
		        }
		    }
	    }
	    //print_r($pairs);
	    $url='';
	    if(count($pairs)>0){
	    	$url= '?'.implode('&', $pairs);
	    }else{
	    	$url= '';
	    }
		
		
		//echo $total;
		$current_page =  $page;
		if($current_page==''){
			$current_page=1;
		}else{
			$current_page=(int)$current_page;
		}
		
	    $limit = $per_page;
		
		$total_pages=ceil($total/$limit);
		$page_navigation='';
		$first_page_navigation='';
		$last_page_navigation='';
		$start_page_navigation='';
		$end_page_navigation='';
		$p_prew=$current_page-1;
		$p_next=$current_page+1;
		
		$last_number_page='<li><a href="'.($url=='' ? '?' : $url.'&').'page='.$total_pages.'" class="pagenav"><strong>'.$total_pages.'</strong></a></li>';
		
		if($current_page==1){
			$first_page_navigation.='<li><span class="pagenav">&laquo;&laquo; </span></li>';
		}else{
			$first_page_navigation.='<li><a href="'.($url=='' ? '?' : $url.'&').'page=1" class="pagenav" title=" ">&laquo;&laquo; </a></li>';
		}
		
		if($current_page==$total_pages){
			$last_page_navigation.='<li><span class="pagenav"> &raquo;&raquo;</span></li>';
			$last_number_page='';
		}else{
			$last_page_navigation.='<li><a href="'.($url=='' ? '?' : $url.'&').'page='.$total_pages.'" class="pagenav" title=" "> &raquo;&raquo;</a></li>';
		}
		
		if($p_prew<1){
			$start_page_navigation.='<li><span class="pagenav">&laquo; </span></li>';
		}else{
			$start_page_navigation.='<li><a href="'.($url=='' ? '?' : $url.'&').'page='.$p_prew.'" class="pagenav" title="">&laquo; </a></li>';
		}
		
		if($p_next>$total_pages){
			$end_page_navigation.='<li><span class="pagenav"> &raquo;</span></li>';
		}else{
			$end_page_navigation.='<li><a href="'.($url=='' ? '?' : $url.'&').'page='.$p_next.'" class="pagenav" title=""> &raquo;</a></li>';
		}
		
		
		$linestart=$current_page-7;
		$lineend=$current_page+7;
		
		if($linestart<=1){
			$linestart=1;
			$lineprefix='';
		}else{
			$lineprefix='...';
		}
		
		if($lineend>=$total_pages){
			$lineend=$total_pages;
			$last_number_page='';
			$linepostfix='';
		}
		else{
			$linepostfix='...';
		}
		
		
		
		//for($i=1;$i<=$total_pages;$i++){
		for($i=$linestart;$i<=$lineend;$i++){
			if($current_page==$i){
				$page_navigation.='<li><span class="pagenav"> '.$i.' </span></li>';
			}else{
				$page_navigation.='<li><a href="'.($url=='' ? '?' : $url.'&').'page='.$i.'" class="pagenav"><strong>'.$i.'</strong></a></li>';
			}
		}
		$page_navigation='<ul class="pagination">'.$first_page_navigation.$start_page_navigation.$lineprefix.$page_navigation.$linepostfix.$end_page_navigation.$last_number_page.$last_page_navigation.'</ul>';
	    return $page_navigation;
	}
    
    /**
     * Get image list admin
     * @param string $action action
     * @param string $table_name table name
     * @param string $key key
     * @param int $record_id record id
     * @param int $limit limit value
     * @return string
     */
    function get_image_array ( $action, $table_name, $key, $record_id, $limit = 0 ) {
    	global $__db_prefix;
    	$url = $this->storage_dir;
    	$ra=array();
    	
    	$query = "select i.* from ".DB_PREFIX."_".$table_name."_image as li, ".IMAGE_TABLE." as i where li.".$key."=$record_id and li.image_id=i.image_id order by li.sort_order";
    	if ( $limit > 0 ) {
    		$query .= ' limit '.$limit;
    	}
    	$this->db->exec($query);
    	$i = 0;
    	while ( $this->db->fetch_assoc() ) {
    	    $ra[$i]['preview'] =  $this->db->row['preview'];
    	    $ra[$i]['normal'] =  $this->db->row['normal'];
    	    
    	    $ra[$i]['title'] =  $this->db->row['title'];
    	    $ra[$i]['description'] =  $this->db->row['description'];
    	    	
    	    $ra[$i]['img_preview'] =  $url.''.$this->db->row['preview'];
    	    $ra[$i]['img_normal'] =  $url.''.$this->db->row['normal'];
    	    $i++; 
    	}
    	return $ra;
    }
    
    
    /**
     * Get category breadcrumbs
     * @param array $params
     * @param array $category_structure
     * @param string $url
     * @return string
     */
    function get_category_breadcrumbs( $params, $category_structure, $url = '' ) {
        $rs = '';
        
        if ( !isset($params['topic_id']) ) {
            return $rs;
        }
        //foreach ( $category_structure['childs'][0] as $item_id => $catalog_id ) {
        if($category_structure['catalog'][$params['topic_id']]['url']!=''){
        	$ra[] = '<a href="'.rtrim($url,'/').'/'.$category_structure['catalog'][$params['topic_id']]['url'].'">'.$category_structure['catalog'][$params['topic_id']]['name'].'</a>';
        }else{
        	$ra[] = '<a href="'.rtrim($url,'/').'/topic'.$params['topic_id'].'.html">'.$category_structure['catalog'][$params['topic_id']]['name'].'</a>';
        }
        
        $parent_category_id = $category_structure['catalog'][$params['topic_id']]['parent_id'];
        while ( $category_structure['catalog'][$parent_category_id]['parent_id'] != 0 ) {
            if ( $j++ > 100 ) {
                return;
            }
	        if($category_structure['catalog'][$parent_category_id]['url']!=''){
	        	$ra[] = '<a href="'.rtrim($url,'/').'/'.$category_structure['catalog'][$parent_category_id]['url'].'">'.$category_structure['catalog'][$parent_category_id]['name'].'</a>';
	        }else{
	        	$ra[] = '<a href="'.rtrim($url,'/').'/topic'.$parent_category_id.'.html">'.$category_structure['catalog'][$parent_category_id]['name'].'</a>';
	        }
            $parent_category_id = $category_structure['catalog'][$parent_category_id]['parent_id'];
        }
        if ( $category_structure['catalog'][$parent_category_id]['name'] != '' ) {
       	 	if($category_structure['catalog'][$parent_category_id]['url']!=''){
	        	$ra[] = '<a href="'.rtrim($url,'/').'/'.$category_structure['catalog'][$parent_category_id]['url'].'">'.$category_structure['catalog'][$parent_category_id]['name'].'</a>';
	        }else{
	        	$ra[] = '<a href="'.rtrim($url,'/').'/topic'.$parent_category_id.'.html">'.$category_structure['catalog'][$parent_category_id]['name'].'</a>';
	        }
        }
      	$ra[]='<a href="'.SITEBILL_MAIN_URL.'/">'.Multilanguage::_('L_HOME').'</a>';
        $rs = implode(' / ', array_reverse($ra));
        return $rs;
    }
    
    /**
     * Get category breadcrumbs
     * @param array $params
     * @param array $category_structure
     * @param string $url
     * @return string
     */
    function get_category_breadcrumbs_string( $params, $category_structure, $url = '' ) {
        $rs = '';
        $ra[] = ''.$category_structure['catalog'][$params['topic_id']]['name'].'';
        $parent_category_id = $category_structure['catalog'][$params['topic_id']]['parent_id'];
        while ( isset($category_structure['catalog'][$parent_category_id]['parent_id']) && $category_structure['catalog'][$parent_category_id]['parent_id'] != 0 ) {
            if ( $j++ > 100 ) {
                return;
            }
            $ra[] = ''.$category_structure['catalog'][$parent_category_id]['name'].'';
            $parent_category_id = $category_structure['catalog'][$parent_category_id]['parent_id'];
        }
        if ( isset($category_structure['catalog'][$parent_category_id]['name']) && $category_structure['catalog'][$parent_category_id]['name'] != '' ) {
            $ra[] = ''.$category_structure['catalog'][$parent_category_id]['name'].'';
        }
        $rs = implode(' / ', array_reverse($ra));
        return $rs;
    }
    
    /**
     * Make preview
     * @param
     * @return
     */
    function makePreview ( $src, $dst, $width, $height, $ext='jpg', $md=0 ) {
        if ($ext=='jpg' || $ext=='jpeg'){
        	$source_img=ImageCreateFromJPEG($src);
        } elseif ($ext=='png') {
        	$source_img=ImageCreateFromPNG($src);
        } elseif ($ext=='gif') {
        	$source_img=ImageCreateFromGIF($src);
        }
          
        $w_src=imagesx($source_img);
        $h_src=imagesy($source_img);
        if ($w_src>$h_src) {$mode='width';}else{$mode='height';}
        if ($md=='height') {$mode='height';}
        if ($md=='width') {$mode='width';}
        $ratio=1;
        if ($mode=='width') {
            if ($w_src>$width){$ratio=$w_src/$width;}
        } else {
            $tmp=$width;$width=$height;$height=$tmp;
            if ($h_src>$height){$ratio=$h_src/$height;}
        }
        $width_tmp=intval($w_src/$ratio);
        $height_tmp=intval($h_src/$ratio); 
        $tmp_img=imagecreatetruecolor($width_tmp,$height_tmp);
        imagecopyresampled($tmp_img, $source_img,0,0,0,0,$width_tmp,$height_tmp,$w_src,$h_src);
        
        if ($ext=='jpg' || $ext=='jpeg'){
        	imagejpeg($tmp_img,$dst);
        }elseif($ext=='png'){
        	imagepng($tmp_img,$dst);
        }elseif($ext=='gif'){
        	imagegif($tmp_img,$dst);
        } 
        ImageDestroy($source_img);
        ImageDestroy($tmp_img);
        // ImageDestroy($preview_img);
        return array($width,$height);
    }
    
    /**
     * Make move 
     * @param
     * @return
     */
    function makeMove ( $src, $dst ) {
        @rename($src, $dst);
    }
    
    /**
     * return id of Admininstrator 
     * @param
     * @return int
     */   
	function getAdminUserId(){
    	$query = "select user_id from ".DB_PREFIX."_user where login='admin'";
        $this->db->exec($query);
        $this->db->fetch_assoc();
        return $this->db->row['user_id'];
    }
    
/**
     * return Vendor info 
     * @param id integer
     * @return string
     */   
	function getVendorInfoById($id){
    	$query = "select * from ".DB_PREFIX."_vendor where vendor_id=$id";
        $this->db->exec($query);
        if($this->db->success){
        	$this->db->fetch_assoc();
        	return $this->db->row;
        }else{
        	return array();
        }
    }
    
    function getUnregisteredUserId(){
    	$query = "SELECT user_id FROM ".DB_PREFIX."_user WHERE login='_unregistered'";
    	$this->db->exec($query);
    	if($this->db->success){
        	$this->db->fetch_assoc();
        	return $this->db->row['user_id'];
        }else{
        	return 0;
        }
    }
    
    function growCounter($table_name,$primary_key_name,$primary_key_value,$user_id=0){
    	$query='UPDATE '.DB_PREFIX.'_'.$table_name.' SET view_count=view_count+1 WHERE '.$primary_key_name.'='.$primary_key_value.' AND user_id<>'.$user_id;
    	$this->db->exec($query);
    }
    
	function transliteMe($str){
		$str=str_replace(array(',','.','/','\\','"','\'', '~', '!', '@', '#', '$', '%', '^', '&', '*', '(', ')', '_', '+', '|', ';', '?', '<', '>', '`', '[', ']', '{', '}', '' ), '', $str);
		$str = strtolower($str);
		$tr = array(
        ""=>"a",""=>"b",
        ""=>"v",""=>"g",""=>"d",""=>"e",""=>"e",""=>"j",
        ""=>"z",""=>"i",""=>"y",""=>"k",""=>"l",
        ""=>"m",""=>"n",""=>"o",""=>"p",""=>"r",
        ""=>"s",""=>"t",""=>"u",""=>"f",""=>"h",
        ""=>"ts",""=>"ch",""=>"sh",""=>"sch",""=>"y",
        ""=>"yi",""=>"",""=>"e",""=>"yu",""=>"ya", 
        
		""=>"a",""=>"b",
        ""=>"v",""=>"g",""=>"d",""=>"e",""=>"e",""=>"j",
        ""=>"z",""=>"i",""=>"y",""=>"k",""=>"l",
        ""=>"m",""=>"n",""=>"o",""=>"p",""=>"r",
        ""=>"s",""=>"t",""=>"u",""=>"f",""=>"h",
        ""=>"ts",""=>"ch",""=>"sh",""=>"sch",""=>"y",
        ""=>"yi",""=>"",""=>"e",""=>"yu",""=>"ya", 
		
		" "=> "-"
    	);
    	//preg_replace
    	return strtr(strtolower($str),$tr);
	}
	
	function validateEmailFormat($email){
		if(preg_match('/^[0-9a-z]+[-\._0-9a-z]*@[0-9a-z]+[-\._^0-9a-z]*[0-9a-z]+[\.]{1}[a-z]{2,6}$/',strtolower($email))){
			return true;
		}else{
			return false;
		}
	}
	
	function validateMobilePhoneNumberFormat($phone_number){
		if ( $this->getConfigValue('apps.fasteditor.enable') ) {
			$clear_number=preg_replace('/[^\d]/', '', $phone_number);
			if(preg_match('/^8(\d){10}$/',$clear_number)){
				return $clear_number;
			}else{
				return FALSE;
			}
        }else{
        	return TRUE;
        }
		
	}
	
	public static function getAttachmentsBlock(){
		global $smarty;
		return $smarty->fetch(SITEBILL_DOCUMENT_ROOT.'/apps/admin/admin/template/attachments_block.tpl');
	}
	
	public static function modelSimplification($model){
		foreach($model as $mkey=>$melement){
			foreach($melement as $k=>$v){
				if($k=='type' && ($v!='select_by_query' && $v!='select_box' && $v!='select_box_structure' && $v!='structure')){
					$model[$mkey]['value_string']=$model[$mkey]['value'];
				}
				if(!in_array($k, array('name','title','value','value_string','type','image_array'))){
					unset($model[$mkey][$k]);
				}
				
			}
		}
		return $model;
	}
	
	public static function iconv($in_charset, $out_charset, $string){
		if(strtolower($in_charset)==strtolower($out_charset)){
			return $string;
		}else{
			return iconv($in_charset, $out_charset, $string);
		}
		
	}
}
?>