<?php
/**
 * Construct grid
 * @author Kondin Dmitriy <kondin@etown.ru> http://www.sitebill.ru
 */
class Common_Grid extends Sitebill {
    /**
     * Array with list of grid items
     * @var array
     */
    protected $grid_items = array();

    /**
     * Array with list of grid controls (edit/delete/structure/manual)
     * @var array
     */
    protected $grid_controls = array();
    
    /**
     * 
     * @var string
     */
    protected $grid_query;
    
    /**
     * Grid object
     * @var object
     */
    protected $grid_object;
    
    protected $pager_params=array();
    
    function __construct ( $grid_object ) {
        $this->SiteBill();
        $this->grid_object = $grid_object;        
    }

    /**
     * Add grid item
     * @param string $name
     * @return void
     */
    function add_grid_item ( $name ) {
        array_push($this->grid_items, $name);
    }
    
    /**
     * Add grid control
     * @param string $name
     * @return void
     */
    function add_grid_control ( $name ) {
        array_push($this->grid_controls, $name);
    }
    
    
    
    /**
     * Set SQL-query for load records 
     * @param string $query
     * @return void
     */
    function set_grid_query ( $query ) {
    	//echo $query.'<br>';
        $this->grid_query = $query;
    }
    
    function construct_grid ( $control_params = false, $disable_mass_delete = false ) {
        $ra = array();
        $query=$this->grid_query.' '.(isset($this->per_page) ? 'LIMIT '.(($this->current_page-1)*$this->per_page).', '.$this->per_page : '');
        $this->db->exec($query);
        if($this->db->num_rows()==0 && $this->current_page!=1){
        	$this->current_page=1;
        	$query=$this->grid_query.' '.(isset($this->per_page) ? 'LIMIT '.(($this->current_page-1)*$this->per_page).', '.$this->per_page : '');
        	$this->db->exec($query);
        }
        if ( !$this->db->success ) {
        	echo $this->db->error;
        	return false;
        }
        //$this->db->exec($this->grid_query);
        while ( $this->db->fetch_assoc() ) {
            $ra[$this->db->row[$this->grid_object->primary_key]] = $this->db->row;
        }
        if(count($ra)>0){
	        $rs = '<table border="0" width="99%" class="table table-hover">';
	        $rs .= '<thead>';
	        $rs .= '<tr>';
	        if ( !$disable_mass_delete ) {
	        	$rs .= '<th class="row_title" width="1%"><input type="checkbox" class="grid_check_all" /></td>';
	        }
	        foreach ( $this->grid_items as $item_id => $item_name ) {
	        	
	            $rs .= '<th class="row_title"';
	            if ( $this->grid_object->data_model[$this->grid_object->table_name][$item_name]['type'] == 'primary_key' ) {
	                $rs .= 'width="1%"';
	            }
	            $rs .= '>'.$this->grid_object->data_model[$this->grid_object->table_name][$item_name]['title'].'</th>';
	        }
	        if ( count($this->grid_controls) > 0 ) {
	            $rs .= '<th class="row_title" width="1%"></th>';
	        }
	        $rs .= '</tr>';
	        $rs .= '</thead>';
	        $rs .= '<tbody>';
	        foreach ( $ra as $primary_key_value => $item_array ) {
	            $row_data = $this->grid_object->load_by_id($primary_key_value);
	            if(count($this->grid_controls) > 0){
	        		$rs .= '<script>';
					$rs .= 'jQuery(document).ready(function(){';
					$rs .= '	jQuery(\'tr.row3 td\').not(\'td:has(a), td:has(input[type=checkbox])\').css({\'cursor\':\'pointer\'}).click(function(){';
					$rs .= '		var alt=$(this).parent(\'tr\').attr(\'alt\');';
					$rs .= '		window.location.replace(alt);';
					$rs .= '	});';
					$rs .= '});';
					$rs .= '</script>';
	        		$rs .= '<tr class="row3" alt="?action='.$this->grid_object->action.'&do=edit&'.$this->grid_object->primary_key.'='.$primary_key_value.'">';
	        	}else{
	        		$rs .= '<tr class="row3" alt="">';
	        	}
	        	if ( !$disable_mass_delete ) {
	        		$rs .= '<td><input type="checkbox" class="grid_check_one" value="'.$primary_key_value.'" /></td>';
	        	}
	        	$grid_counter = 0;
	            foreach ( $this->grid_items as $item_id => $item_name ) {
	                $grid_counter++;
	            	
	            	if($row_data[$item_name]['type']=='select_by_query'){
	            		$rs .= '<td>'.$row_data[$item_name]['value_string'].'</td>';
	            	}elseif($row_data[$item_name]['type']=='structure'){
	            		$rs .= '<td>'.$row_data[$item_name]['value_string'].'</td>';
	            	}elseif ($row_data[$item_name]['type']=='date') {
	            		$rs .= '<td  >'.$row_data[$item_name]['value'].'</td>';
	                }elseif ($row_data[$item_name]['type']=='select_box') {
	                    $rs .= '<td  >'.$row_data[$item_name]['select_data'][$row_data[$item_name]['value']].'</td>';
	                }elseif($row_data[$item_name]['type']=='checkbox'){
						$rs .= '<td>'.($row_data[$item_name]['value']==1 ? '<img src="'.SITEBILL_MAIN_URL.'/apps/admin/admin/template/img/radio_yes.png">' : '<img src="'.SITEBILL_MAIN_URL.'/apps/admin/admin/template/img/radio_no.png">').'</td>';
					} else { 
						if(is_array($row_data[$item_name]['value'])){
							$rs .= '<td>'.implode(';',$row_data[$item_name]['value']).'</td>';
						}else{
							$rs .= '<td>'.$row_data[$item_name]['value'].'</td>';
						}
	            		
	            	}
	                
	            }
	            if ( count($this->grid_controls) > 0 ) {
	                $rs .= '<td nowrap>';
	                
	                foreach ( $this->grid_controls as $control_id => $control_name ) {
	                	if ( $control_name == 'view' ) {
	                		if ( !empty($control_params['view']) ) {
	                			$control_params_edit_string = $control_params['view'];
	                		}
	                		$rs .= ' <a href="?action='.$this->grid_object->action.'&do=view&'.$this->grid_object->primary_key.'='.$primary_key_value.$control_params_edit_string.'" class="btn btn-info"><i class="icon-white icon-info-sign"></i></a> ';
	                	}
	                    if ( $control_name == 'edit' ) {
	                    	if ( !empty($control_params['edit']) ) {
	                    		$control_params_edit_string = $control_params['edit']; 
	                    	}
	                        $rs .= ' <a href="?action='.$this->grid_object->action.'&do=edit&'.$this->grid_object->primary_key.'='.$primary_key_value.$control_params_edit_string.'" class="btn btn-info"><i class="icon-white icon-pencil"></i></a> ';
	                    }
	                    if ( $control_name == 'delete' ) {
	                    	if ( !empty($control_params['delete']) ) {
	                    		$control_params_delete_string = $control_params['delete'];
	                    	}
	                    	
	                        $rs .= ' <a href="?action='.$this->grid_object->action.'&do=delete&'.$this->grid_object->primary_key.'='.$primary_key_value.$control_params_delete_string.'" onclick="if ( confirm(\'   ?\') ) {return true;} else {return false;}" class="btn btn-danger"><i class="icon-white icon-remove"></i></a> ';
	                    }
	                }
	                $rs .= '</td>';
	            }
	            
	            $rs .= '</tr>';
	        }
	        if ( !$disable_mass_delete ) {
	        	$rs .= '<tr><td colspan="'.(count($this->grid_controls)+$grid_counter).'"><button alt="'.$this->grid_object->action.'" class="delete_checked btn btn-danger"><i class="icon-white icon-remove"></i> '.Multilanguage::_('L_DELETE_CHECKED').'</button></td></tr>';
	        }
	        $rs .= '<tr><td colspan="'.(count($this->grid_controls)+$grid_counter).'" class="pager"><div align="center">'.$this->getPager().'</div></td></tr>';
	         
	        $rs .= '</tbody>';
	         
	        $rs .= '</table>';
        }else{
        	$rs.='<br><br>  ';
        }
        
        return $rs;
    }
    
    function construct_grid_array () {
    	$ra = array();
    
    	$query=$this->grid_query.' LIMIT '.(($this->current_page-1)*$this->per_page).', '.$this->per_page;
    	$this->db->exec($query);
    
    	while ( $this->db->fetch_assoc() ) {
    		$ra[$this->db->row[$this->grid_object->primary_key]] = $this->db->row;
    	}
    
    	$ret=array();
    	//
    	foreach ( $ra as $primary_key_value => $item_array ) {
    		$row_data = $this->grid_object->load_by_id($primary_key_value);
    		//
    		$data=array();
    		foreach ( $this->grid_items as $item_id => $item_name ) {
    			//echo 'type = '.$row_data[$item_name]['type'].', name = '.$row_data[$item_name]['name'].'<br>';
    			if($row_data[$item_name]['type']=='select_by_query'){
    				$data[$item_name]['value']=$row_data[$item_name]['value'];
    				$data[$item_name]['value_string']=$row_data[$item_name]['value_string'];
    			}elseif ($row_data[$item_name]['type']=='date') {
    				$data[$item_name]= $row_data[$item_name]['value'];
    				//$data[$item_name]=date('d.m.Y', $row_data[$item_name]['value']);
    			}elseif ($row_data[$item_name]['type']=='select_box') {
    				$data[$item_name]=$row_data[$item_name]['select_data'][$row_data[$item_name]['value']];
    			} elseif ($row_data[$item_name]['type']=='geodata'){
    				$data[$item_name]=implode(',',$row_data[$item_name]['value']);
    			}else {
    				$data[$item_name]=$row_data[$item_name]['value'];
    			}
    			 
    
    		}
    		$ret[]=$data;
    	}
    	return $ret;
    }
    
    
    function getPager(){
    	$this->db->exec($this->grid_query);
    	$total=$this->db->num_rows();
    	$ret=$this->get_page_links_list($this->current_page, $total, $this->per_page, $this->pager_params);
    	return $ret;
    }
    
    function setPagerParams($params=array()){
    	if(isset($params['per_page']) AND ($params['per_page']!=0)){
    		$this->per_page=(int)$params['per_page'];
    	}else{
    		$this->per_page=10;
    	}
    	
    	if(isset($params['page']) AND ($params['page']!=0)){
    		$this->current_page=(int)$params['page'];
    	}else{
    		$this->current_page=1;
    	}
    	
    	unset($params['per_page']);
    	unset($params['page']);
    	
    	$this->pager_params=$params;
    	
    }
    
	
    
} 
?>
